@@ -1,9 +1,9 @@
 /*
  * ansilove.c
- * Ansilove 4.0.6
+ * Ansilove 4.1.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause License.
@@ -34,6 +34,7 @@
 #include "fonts.h"
 #include "sauce.h"
 #include "strtolower.h"
+#include "types.h"
 
 /* prototypes */
 static void synopsis(void);
@@ -45,14 +46,14 @@ synopsis(void)
 	fprintf(stdout, "SYNOPSIS\n"
 	    "     ansilove [-dhiqrsv] [-b bits] [-c columns] [-f font]"
 	    " [-m mode] [-o file]\n"
-	    "              [-R factor] file\n");
+	    "              [-R factor] [-t type] file\n");
 }
 
 static void
 version(void)
 {
 	fprintf(stdout, "AnsiLove/C %s - ANSI / ASCII art to PNG converter\n"
-	    "Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and "
+	    "Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and "
 	    "Frederic Cambus.\n", VERSION);
 }
 
@@ -65,17 +66,13 @@ main(int argc, char *argv[])
 	bool justDisplaySAUCE = false;
 	bool fileHasSAUCE = false;
 
-	/* analyze options and do what has to be done */
-	bool fileIsBinary = false;
-	bool fileIsANSi = false;
-	bool fileIsPCBoard = false;
-	bool fileIsTundra = false;
-
 	int getoptFlag;
 
 	char *input = NULL, *output = NULL;
 	char *fileName = NULL;
 	char *font = NULL;
+	char *type = NULL;
+	int filetype = 0;
 
 	static struct ansilove_ctx ctx;
 	static struct ansilove_options options;
@@ -100,10 +97,9 @@ main(int argc, char *argv[])
 	if (ansilove_init(&ctx, &options) == -1)
 		errx(EXIT_FAILURE, "%s", ansilove_error(&ctx));
 
-	while ((getoptFlag = getopt(argc, argv, "b:c:df:him:o:qrR:sv")) != -1) {
+	while ((getoptFlag = getopt(argc, argv, "b:c:df:him:o:qrR:st:v")) != -1) {
 		switch (getoptFlag) {
 		case 'b':
-			/* convert numeric command line flags to integer values */
 			options.bits = strtonum(optarg, 8, 9, &errstr);
 
 			if (errstr)
@@ -111,7 +107,6 @@ main(int argc, char *argv[])
 
 			break;
 		case 'c':
-			/* convert numeric command line flags to integer values */
 			options.columns = strtonum(optarg, 1, 4096, &errstr);
 
 			if (errstr)
@@ -155,7 +150,6 @@ main(int argc, char *argv[])
 			options.scale_factor = 2;
 			break;
 		case 'R':
-			/* convert numeric command line flags to integer values */
 			options.scale_factor = strtonum(optarg, 2, 8, &errstr);
 
 			if (errstr)
@@ -165,6 +159,9 @@ main(int argc, char *argv[])
 		case 's':
 			justDisplaySAUCE = true;
 			break;
+		case 't':
+			type = strtolower(optarg);
+			break;
 		case 'v':
 			version();
 			return EXIT_SUCCESS;
@@ -186,7 +183,7 @@ main(int argc, char *argv[])
 		messages = stdout;
 
 	/* let's check the file for a valid SAUCE record */
-	sauce *record = sauceReadFileName(input);
+	struct sauce *record = sauceReadFileName(input);
 
 	/* record == NULL also means there is no file, we can stop here */
 	if (record == NULL) {
@@ -227,27 +224,41 @@ main(int argc, char *argv[])
 		if (fileHasSAUCE)
 			ctx.length -= 129 - (record->comments > 0 ? 5 + 64 * record->comments : 0);
 
-		int (*loader)(struct ansilove_ctx *, struct ansilove_options *);
+		/* set icecolors to true if defined in SAUCE record ANSiFlags */
+		if (fileHasSAUCE && (record->flags & 1))
+			options.icecolors = true;
 
-		/* create the output PNG data by invoking the appropriate function */
-		if (!strcmp(fext, "pcb")) {
-			loader = ansilove_pcboard;
-			fileIsPCBoard = true;
-		} else if (!strcmp(fext, "bin")) {
-			loader = ansilove_binary;
-			fileIsBinary = true;
-		} else if (!strcmp(fext, "adf")) {
-			loader = ansilove_artworx;
-		} else if (!strcmp(fext, "idf")) {
-			loader = ansilove_icedraw;
-		} else if (!strcmp(fext, "tnd")) {
-			loader = ansilove_tundra;
-			fileIsTundra = true;
-		} else if (!strcmp(fext, "xb")) {
-			loader = ansilove_xbin;
-		} else {
+		int (*loader)(struct ansilove_ctx *, struct ansilove_options *) = NULL;
+
+		/* if type was specified, attempt to find a loader */
+		if (type) {
+			for (size_t loop = 0; loop < TYPES; loop++) {
+				if (!strcmp(types[loop], type)) {
+					loader = loaders[loop];
+					filetype = filetypes[loop];
+					break;
+				}
+			}
+
+			if (!loader)
+				errx(EXIT_FAILURE, "Unknown file type.");
+		}
+
+		/* use file extension to find a suitable loader */
+		if (!loader) {
+			for (size_t loop = 0; loop < TYPES; loop++) {
+				if (!strcmp(types[loop], fext)) {
+					loader = loaders[loop];
+					filetype = filetypes[loop];
+					break;
+				}
+			}
+		}
+
+		/* default to ANSI if file extension is unknown */
+		if (!loader) {
 			loader = ansilove_ansi;
-			fileIsANSi = true;
+			filetype = ANSILOVE_FILETYPE_ANS;
 		}
 
 		if (loader(&ctx, &options) == -1)
@@ -258,18 +269,19 @@ main(int argc, char *argv[])
 			errx(EXIT_FAILURE, "%s", ansilove_error(&ctx));
 
 		/* gather information and report to the command line */
-		if (fileIsANSi || fileIsBinary ||
-		    fileIsPCBoard || fileIsTundra) {
+		switch(filetype) {
+		case ANSILOVE_FILETYPE_ANS:
+		case ANSILOVE_FILETYPE_BIN:
+			if (options.icecolors)
+				fprintf(messages, "iCE Colors: enabled\n");
+
+			/* FALLTHROUGH */
+		case ANSILOVE_FILETYPE_PCB:
+		case ANSILOVE_FILETYPE_TND:
 			fprintf(messages, "Font: %s\n", font ? font : "80x25");
-
 			fprintf(messages, "Bits: %d\n", options.bits);
-		}
-
-		if (options.icecolors && (fileIsANSi || fileIsBinary))
-			fprintf(messages, "iCE Colors: enabled\n");
-
-		if (fileIsANSi || fileIsBinary || fileIsTundra)
 			fprintf(messages, "Columns: %d\n", options.columns);
+		}
 
 		if (options.scale_factor)
 			fprintf(messages, "Scale factor: %d\n", options.scale_factor);
@@ -289,27 +301,27 @@ main(int argc, char *argv[])
 		fprintf(messages, "Date: %s\n", record->date);
 		fprintf(messages, "Datatype: %d\n", record->dataType);
 		fprintf(messages, "Filetype: %d\n", record->fileType);
-		if (record->flags) {
+
+		if (record->flags)
 			fprintf(messages, "Flags: %d\n", record->flags);
-		}
-		if (record->tinfo1) {
+
+		if (record->tinfo1)
 			fprintf(messages, "Tinfo1: %d\n", record->tinfo1);
-		}
-		if (record->tinfo2) {
+
+		if (record->tinfo2)
 			fprintf(messages, "Tinfo2: %d\n", record->tinfo2);
-		}
-		if (record->tinfo3) {
+
+		if (record->tinfo3)
 			fprintf(messages, "Tinfo3: %d\n", record->tinfo3);
-		}
-		if (record->tinfo4) {
+
+		if (record->tinfo4)
 			fprintf(messages, "Tinfo4: %d\n", record->tinfo4);
-		}
+
 		fprintf(messages, "Tinfos: %s\n", record->tinfos);
 		if (record->comments > 0) {
 			fprintf(messages, "Comments: ");
-			for (int32_t i = 0; i < record->comments; i++) {
+			for (int32_t i = 0; i < record->comments; i++)
 				fprintf(messages, "%s\n", record->comment_lines[i]);
-			}
 		}
 	}
 
