@@ -1,9 +1,9 @@
 /*
  * config.h
- * Ansilove 4.0.6
+ * Ansilove 4.1.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause License.
@@ -16,6 +16,11 @@
 #include <stdint.h>
 
 /* configuration defines */
-#define VERSION "4.0.6"
+#define VERSION "4.1.0"
+
+enum {
+	FONTS = 38,
+	TYPES = 7
+};
 
 #endif /* CONFIG_H */
