@@ -1,9 +1,9 @@
 /*
  * sauce.c
- * Ansilove 4.0.6
+ * Ansilove 4.1.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause License.
@@ -19,7 +19,7 @@
 #include "sauce.h"
 
 /* Reads SAUCE via a filename. */
-sauce *
+struct sauce *
 sauceReadFileName(char *fileName)
 {
 	FILE *file = fopen(fileName, "r");
@@ -27,16 +27,16 @@ sauceReadFileName(char *fileName)
 		return NULL;
 	}
 
-	sauce *record = sauceReadFile(file);
+	struct sauce *record = sauceReadFile(file);
 	fclose(file);
 	return record;
 }
 
 /* Read SAUCE via a FILE pointer. */
-sauce *
+struct sauce *
 sauceReadFile(FILE *file)
 {
-	sauce *record;
+	struct sauce *record;
 	record = malloc(sizeof *record);
 	memset(record, 0, sizeof *record);
 
@@ -47,9 +47,9 @@ sauceReadFile(FILE *file)
 }
 
 void
-readRecord(FILE *file, sauce *record)
+readRecord(FILE *file, struct sauce *record)
 {
-	if (fseek(file, 0 - RECORD_SIZE, SEEK_END) != EXIT_SUCCESS) {
+	if (fseek(file, 0 - RECORD_SIZE, SEEK_END) != 0) {
 		return;
 	}
 
@@ -81,7 +81,7 @@ readRecord(FILE *file, sauce *record)
 	fread(record->tinfos, sizeof (record->tinfos) - 1, 1, file);
 	record->tinfos[sizeof (record->tinfos) - 1] = '\0';
 
-	if (ferror(file) != EXIT_SUCCESS) {
+	if (ferror(file) != 0) {
 		return;
 	}
 
@@ -101,7 +101,7 @@ readComments(FILE *file, char **comment_lines, int32_t comments)
 {
 	int32_t i;
 
-	if (fseek(file, 0 - (RECORD_SIZE + 5 + COMMENT_SIZE *comments), SEEK_END) == EXIT_SUCCESS) {
+	if (fseek(file, 0 - (RECORD_SIZE + 5 + COMMENT_SIZE *comments), SEEK_END) == 0) {
 		char ID[6];
 		fread(ID, sizeof (ID) - 1, 1, file);
 		ID[sizeof (ID) - 1] = '\0';
@@ -116,7 +116,7 @@ readComments(FILE *file, char **comment_lines, int32_t comments)
 			fread(buf, COMMENT_SIZE, 1, file);
 			buf[COMMENT_SIZE] = '\0';
 
-			if (ferror(file) == EXIT_SUCCESS) {
+			if (ferror(file) == 0) {
 				comment_lines[i] = strdup(buf);
 				if (comment_lines[i] == NULL) {
 					return -1;
