@@ -1,9 +1,9 @@
 /*
  * sauce.h
- * Ansilove 4.0.6
+ * Ansilove 4.1.0
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * Ansilove is licensed under the BSD 2-Clause License.
@@ -22,7 +22,7 @@
 #define SAUCE_ID     "SAUCE"
 #define COMMENT_ID   "COMNT"
 
-typedef struct {
+struct sauce {
 	char ID[6];
 	char version[3];
 	char title[36];
@@ -40,11 +40,11 @@ typedef struct {
 	unsigned char flags;
 	char tinfos[23];
 	char **comment_lines;
-} sauce;
+};
 
-sauce	*sauceReadFileName(char *fileName);
-sauce	*sauceReadFile(FILE *file);
-void	 readRecord(FILE *file, sauce *record);
-int	 readComments(FILE *file, char **comment_lines, int32_t comments);
+struct sauce	*sauceReadFileName(char *);
+struct sauce	*sauceReadFile(FILE *);
+void		 readRecord(FILE *, struct sauce *);
+int		 readComments(FILE *, char **, int32_t);
 
 #endif /* SAUCE_H */
